/**
 * @encoding     UTF-8
 * @package      WordPress Demo Content Manager
 * @link         https://codecanyon.net/item/wordpress-demo-content-manager/20669604
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

(function($, Backbone, dm){
    
    "use strict";
    
    dm.ViewProgress = Backbone.View.extend({
        
        initialize: function () {
            this.listenTo(this.model, 'change', this.animate);
            this.listenTo(this.model, 'change:counts', this.renderSteps);
            this.animate(1);
        },
        
        animate: function (speed) {
            if (speed === undefined) {
                speed = 1500;
            }
            
            var position = this.model.get('current_progress');
            var counts = this.model.get('counts');
            if (counts === undefined) {
                return;
            }
            
            var margin_widths = (counts - 1) * 1.5;
            var step_width = (100 - margin_widths) / counts;
            
            // Animate points
            var self = this;
            this.$('.line').css('width', step_width + '%');
            this.$('.line').each(function(index){
                if (index < position) {
                    $(this).addClass('success');
                    $(this).removeClass('loading warning');
                } else if (index == position && self.model.get('pid')) {
                    $(this).addClass('loading');
                    $(this).removeClass('success warning');
                } else if (index == position && !self.model.get('pid')) {
                    $(this).addClass('warning');
                    $(this).removeClass('success loading');
                } else {
                    $(this).removeClass('success loading warning');
                }
            });
        },
        
        renderSteps: function () {
            var counts = this.model.get('counts');
            if (counts === null || counts < 0 ){
                return;
            }
            
            var $step = this.$('.line').first().clone();
            
            this.$('.line').remove();
            for (var i = 0; i < counts; i++) {
                this.$el.append($step.clone());
            }
        },
        
        changeProgress:  function (int) {
            this.model.set('current_progress', int);
            return true;
        }
        
    });
    
})(jQuery, Backbone, window.wp_demo_manager);
